const path = require('path');

const {
  createPluginPaths,
  createPluginOptions,
} = require('gatsby-source-netlify-cms');

module.exports = ({ basePath, config }) => {
  // We could shadow the ./src/cms/default-config.js in our child theme
  // Or pass a raw config to this plugin
  if (!basePath) {
    throw new Error(`
Missing basePath passed to @talves/gatsby-plugin-data-core.
Make sure to include a basePath in options: { basePath: \`\${__dirname}\` }.
`);
  }
  configExists = config && config.collections;
  if (!configExists) {
    config = require(path.join(basePath, './src/cms/default-config.js'));
  }
  if (!config) {
    throw new Error(`
Missing config passed to @talves/gatsby-plugin-data-core.
Include a config in options: { config: { collections: [...]}},
or have a default config export at './src/cms/default-config.js'.
`);
  }
  // console.log(JSON.stringify(config, null, 2));
  // Create the options for gatsby-source-netlify-cms
  const cmsPluginOptions = createPluginOptions(config);
  // Create the source plugins with paths based on our config
  const cmsPluginPaths = createPluginPaths(config);

  cmsPluginOptions.copyRootPath = basePath || `${__dirname}`;
  return {
    plugins: [
      // Setup the netlify cms source (data)
      {
        resolve: 'gatsby-source-netlify-cms',
        options: cmsPluginOptions,
      }, // Setup the file source plugins for the above
      ...cmsPluginPaths,
    ],
  };
};
